@@ -1,7 +1,9 @@
 pub mod layouts;
 pub mod wt_huff;
+pub mod wt_int;
 
 pub mod crate_export {
     pub use super::layouts::crate_export as layouts;
     pub use super::wt_huff::WtHuff;
+    pub use super::wt_int::WtInt;
 }
