@@ -50,7 +50,7 @@ use crate::interface::wavelet_trees::layouts;
 /// assert_eq!(result, expected);
 /// ```
 ///
-/// For further examples see [here](https://github.com/sdsl-rs/sdsl-rs/blob/master/examples/src/wt_huff.rs).
+/// For further examples see [here](https://github.com/sdsl-rs/sdsl-rs/blob/master/examples/src/wavelet_trees/wt_huff.rs).
 pub struct WtHuff<
     'a,
     BitVector = crate::bit_vectors::BitVector,
@@ -129,7 +129,9 @@ where
     /// Construct a Huffman-shaped wavelet tree from a bit vector.
     /// # Arguments
     /// * `bit_vector` - Bitvector.
-    pub fn from_bit_vector(bit_vector: &crate::interface::bit_vector::BitVector) -> Result<Self> {
+    pub fn from_bit_vector(
+        bit_vector: &crate::interface::bit_vectors::bit_vector::BitVector,
+    ) -> Result<Self> {
         let id = Self::id()?;
         let interface = Interface::new(&id)?;
         let ptr = (interface.from_bit_vector)(*bit_vector.ptr());
